Color

Struct Color 

pub struct Color;

Implementations

Source

impl Color

pub fn by_enum(&self, color: color) -> [u8; 3]

Get colour rgb array by enum color param.

Example
use color_name::{
    Color,
    color
};
assert_eq!(Color::val().by_enum(color::white), [255, 255, 255]);
pub fn by_string(&self, color: String) -> Result<[u8; 3], u16>

Get colour rgb array by String param.

Example:
use color_name::{
    Color
};
assert_eq!(Color::val().by_string("InDigo".to_string()).expect("Not found"), [75, 0, 130]);

// NOTE: the string can be at any case, it will be converted into Title-case
assert_eq!(Color::val().by_string("inDigo".to_string()).expect("Not found"), [75, 0, 130]);
assert_eq!(Color::val().by_string("IndiGo ".to_string()).expect("Not found"), [75, 0, 130]);

NOTE: Return Result<[u8;3],u16> as color data [u8;3] or Not found (404).

pub fn val() -> Color

Get value of a color by string OR enum.

pub fn name(rgb: [u8; 3]) -> String

Get exact colour name if there’s no data it return “404”.

pub fn similar(rgb: [u8; 3]) -> String

Get closest colour name match the provided rgb data array.

pub fn close_to(rgb: [u8; 3]) -> String

Sweet proxy to simlar(rgb)